VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "IniKey"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'*********************************************************************
'Titolo: Ini Key Class
'Autore: Giorgio Bernardi
'E-Mail: BGSoftware@hotmail.com
'Data  : Novembre 2000
'Descrizione: Questa classe pu essere usata per leggere e scrivere chiavi
'             nei files ini
'Info:  Potete usare e modificare a piacimento questo codice
'*********************************************************************

'Dichiarazione delle Api necessarie
Private Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Private Declare Function GetPrivateProfileSection Lib "kernel32" Alias "GetPrivateProfileSectionA" (ByVal lpAppName As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileSection Lib "kernel32" Alias "WritePrivateProfileSectionA" (ByVal lpAppName As String, ByVal lpString As String, ByVal lpFileName As String) As Long

Public fileName As String
Public Section As String
Public keyName As String

'**************************************************************************
'FUNZIONI PER LA LETTURA DI INFORAMAZIONI DIRETTAMENTE DAL FILE
'**************************************************************************
'
'   Queste funzioni, restituiscono il valore letto da un file.
'   Tutte le funzioni hanno la medesima firma:
'       fileName => Indica il percorso compelto del file da cui leggere
'       Section =>  Indica la sezione in cui si trova la chiave
'       keyName =>  Indica il nome della chiave
'       ok (Opzionale) => Viene impostato a True se il valore  stato letto correttamente, a False nel caso opposto
'       defaultString (Opz) => Indica il valore di default da restituire in caso di errore in lettura (nei diversi casi si tratter di una stringa, un intero ecc...)
'       bufferSize (Opz)    => Indica la lunghezza massima da leggere per il dato. Un intero, per esempio, non pu essere pi lungo di 6 caratteri (5 + il segno)
'
'   Le funzioni utilizzano la getIniString come base ed effettuano la conversione nel tipo appropriato.
'
'   LISTA DELLE FUNZIONI
'       getIniString => Restituisce una stringa
'       getIniBool  =>  Restituisce un valore Booleano
'       getIniInt   =>  Restituisce un valore intero Integer
'       getIniCurr  =>  Restituisce un valore di tipo Currency
'       getIniLong  =>  Restituisce un valore di tipo Long

Public Function getIniString(Optional ok As Boolean = True, Optional ByVal defaultString As String = "", Optional bufferSize As Long = 32000) As String
Dim returnString As String
Dim myDefault As String
Dim StrLen As Long
Dim res As Long

'Inizializzo le variabili
ok = True
If defaultString = "" Then myDefault = Space(32000)
returnString = Space(bufferSize)

'CONTROLLO CHE LA CLASSE SIA STATA INIZILIZZATA CON I VALORI OPPORTUNI
If Not CBool(Len(fileName) * Len(Section) * Len(keyName)) Then
    ok = False
    getIniString = "CLASSE NON INIZIALIZZATA"
    Exit Function
End If

'Richiedo il dato
res = GetPrivateProfileString(Section, keyName, myDefault, returnString, bufferSize, fileName)

'Vedo se la risposta  un errore
If res = 0 Then
    getIniString = defaultString
    ok = False
    Exit Function
End If

'Cerco il carattere chr(0) che chiude la stringa
StrLen = InStr(1, returnString, Chr(0), vbBinaryCompare)

If StrLen <> 0 Then getIniString = Left(returnString, StrLen - 1) Else getIniString = returnString

End Function

Public Function getIniBool(Optional ok As Boolean = True, Optional defaultValue As Boolean = False) As Boolean
Dim tempStr As String
Dim tempRes As Boolean

On Error GoTo err
tempStr = Trim(getIniString(ok))

If ok = False Then GoTo err

tempRes = CBool(tempStr)

getIniBool = tempRes

Exit Function
err:
ok = False          'Indica un errore
getIniBool = defaultValue     'Pu indicare un errore
End Function

Public Function getIniInt(Optional ok As Boolean = True, Optional defaultValue As Integer = -1) As Integer
Dim tempStr As String
Dim tempRes As Integer

On Error GoTo err
tempStr = Trim(getIniString(ok, Space(6), 6))

If ok = False Then GoTo err

tempRes = CInt(tempStr)

getIniInt = tempRes

Exit Function
err:
ok = False          'Indica un errore
getIniInt = defaultValue     'Pu indicare un errore
End Function

Public Function getIniLong(Optional ok As Boolean = True, Optional defaultValue As Long = -1) As Long
Dim tempStr As String
Dim tempRes As Long

On Error GoTo err
tempStr = Trim(getIniString(ok, Space(11), 11))

If ok = False Then GoTo err

tempRes = CLng(tempStr)

getIniLong = tempRes

Exit Function
err:
ok = False          'Indica un errore
getIniLong = defaultValue     'Pu indicare un errore
End Function

Public Function getIniCurr(Optional ok As Boolean = True, Optional defaultValue As Currency = -1) As Currency
Dim tempStr As String
Dim tempRes As Currency

On Error GoTo err
tempStr = Trim(getIniString(ok))

If ok = False Then GoTo err

tempRes = CCur(tempStr)

getIniCurr = tempRes

Exit Function
err:
ok = False          'Indica un errore
getIniCurr = defaultValue     'Pu indicare un errore
End Function

Public Function getIniSection(Optional ok As Boolean = True, Optional ByVal defaultString As String = "", Optional bufferSize As Long = 32000) As String
Dim returnString As String
Dim myDefault As String

Dim StrLen As Long
Dim res As Long

ok = True
myDefault = Space(32000)
returnString = Space(bufferSize)

'CONTROLLO CHE LA CLASSE SIA STATA INIZILIZZATA CON I VALORI OPPORTUNI
If Not CBool(Len(fileName) * Len(Section)) Then
    ok = False
    getIniSection = "CLASSE NON INIZIALIZZATA"
    Exit Function
End If

res = GetPrivateProfileSection(Section, returnString, bufferSize, fileName)

If res = 0 Then
    getIniSection = defaultString
    ok = False
    Exit Function
End If

'Cerco il carattere chr(0) che chiude la stringa
StrLen = InStr(1, returnString, Chr(0) & Chr(0), vbBinaryCompare)
If StrLen <> 0 Then getIniSection = Left(returnString, StrLen - 1) Else getIniSection = returnString

End Function

'**************************************************************************
'FUNZIONI PER LA SCRITTURA DI DATI
'**************************************************************************
'
'   Le funzioni di scrittura richiedono di indicare la posizione di scrittura e i dati da inserire
'   La variabile addLen, viene incrementata con lo spazio occupato nel file dall'inserimento.
'
Public Function setIniVal(ByVal Value As Variant, Optional ByRef addlen As Long) As Boolean
'Utilizzata per ogni tipo di dato. I Boolean vengono automaticamente convertiti
'in True o False in modo da essere letti facilmente con le funzioni sopra indicate
'Restituisce True se la scrittura  andata a buon fine
    
    'CONTROLLO CHE LA CLASSE SIA STATA INIZILIZZATA CON I VALORI OPPORTUNI
    If Not CBool(Len(fileName) * Len(Section) * Len(keyName)) Then
        setIniVal = False
        Exit Function
    End If
    
    setIniVal = CBool(WritePrivateProfileString(Section, keyName, CStr(Value), fileName))
    addlen = addlen + Len(keyName & CStr(Value)) + 3 '1 per = , 2 per ritorno a capo
End Function

Public Function setIniSection(Sezione As String, Optional ByRef addingLen As Long) As Boolean
'Scrive una intera sezione su un file
'Restituisce True se la scrittura  andata a buon fine
'ATTENZIONE: La funzione cancella totalmente i dati presenti in precedenza in quella sezione
    
    'CONTROLLO CHE LA CLASSE SIA STATA INIZILIZZATA CON I VALORI OPPORTUNI
    If Not CBool(Len(fileName)) Then
        setIniSection = False
        Exit Function
    End If
    setIniSection = CBool(WritePrivateProfileSection(NomeSezione, Sezione, fileName))
    addingLen = addingLen + Len(Sezione) + Len(NomeSezione) + 4
End Function
